const AEM = require('./index');
const fetch = require('isomorphic-fetch');
const exec = require('./generatorExec');
require('colors');

const aem = new AEM('http://aem.bwinparty.corp', 4502, 'cashcade_runner', 'Ca$hcad3');

const termsNodes = require('./nodesToModify');

const h5NodeName = 'terms-migration-h5';
const textNodeName = 'terms-migration-text';

exec(function *() {
  const termsLen = termsNodes.length;
  for (let i = 0; i < termsLen; i++) {
    const termsPath = termsNodes[i];
    const cqPage = termsPath.split('/jcr:content/')[0];

    console.log(`${i} / ${termsLen}\t${termsPath}`.blue);
    const termsNode = yield aem.getNode(termsPath).catch(e => null);

    if (termsNode === null) {
      console.log(' - couldnt find terms node'.yellow);
      continue;
    }

    /**
     * Create version
     */
    const page = yield aem.getNode(cqPage);
    yield page.createVersion('', 'Pre-terms to h5 + text conversion');
    console.log(' - version created');

    /**
     * CREATE NEW NODES IF NOT EXIST
     */
    const parentPath = termsPath.replace(/\/([^\/]+?)$/, '');
    const parentNode = yield aem.getNode(parentPath);
    const parentChildNodes = yield parentNode.getChildren();
    if (!parentChildNodes[h5NodeName] || !parentChildNodes[textNodeName]) {
      const props = yield termsNode.getProperties();

      const {headline, text} = props;

      const cleanHeadline = headline ? headline.replace(/£/g, '&pound;') : '';
      const cleanText = text ? text.replace(/£/g, '&pound;') : '';

      /**
       * CREATE H5
       */
      if (!parentChildNodes[h5NodeName]) {
        console.log(` - adding h5 [${headline}]`);

        yield parentNode.createChild(h5NodeName, 'nt:unstructured', {
          headlinesize: 'h5',
          'sling:resourceType': 'libs/foundation/components/subtitle',
          title: cleanHeadline,
          titleText: cleanHeadline,
        });
      }

      /**
       * CREATE TEXT
       */
      if (!parentChildNodes[textNodeName]) {
        console.log(` - adding text`);

        yield parentNode.createChild(textNodeName, 'nt:unstructured', {
          'sling:resourceType': 'basil/components/content/text',
          text: cleanText,
          textIsRich: true,
        });
      }
    } else {
      console.log(' - new nodes already exist. skipping creation');
    }

    /**
     * REMOVE OLD TERMS NODE
     */
    console.log(' - removing terms node');
    yield termsNode.remove();

    /**
     * ACTIVATE PAGE
     */
    // yield page.activate();

    console.log(` - DONE`.green);
  }
});